@@ -1,4 +1,5 @@
-from pydantic import BaseSettings, SecretStr
+from pydantic import SecretStr
+from pydantic_settings import BaseSettings
 
 
 class CommonSettings(BaseSettings):
@@ -7,13 +8,13 @@ class CommonSettings(BaseSettings):
 
 
 class S3Settings(BaseSettings):
-    s3_endpoint_url: str = None
-    s3_region_name: str = None
+    s3_endpoint_url: str | None = None
+    s3_region_name: str | None = None
     s3_access_key_id: SecretStr = ''
     s3_secret_access_key: SecretStr = ''
     s3_secure: bool = True
-    s3_bucket: str = None
-    s3_bucket_root: str = None
+    s3_bucket: str | None = None
+    s3_bucket_root: str | None = None
 
 
 settings = CommonSettings()
